.. AlekSIS documentation master file, created by
   sphinx-quickstart on Thu Aug 15 10:49:03 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to AlekSIS-Core's documentation!
========================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   admin/00_index
   dev/00_index
   ref/00_index


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
